Summary:	Asynchronous JavaScript Engine
Name:		nodejs
Version:	0.10.21
Release:	1
License:	BSD and MIT and Apache v2.0 and GPL v3
Group:		Development/Languages
Source0:	http://nodejs.org/dist/v%{version}/node-v%{version}.tar.gz
# Source0-md5:	774bc17875c042ac42ad2d96b9c96734
Patch1:		%{name}-shared.patch
# force node to use /usr/lib/node as the systemwide module directory
Patch2:		%{name}-libpath.patch
# use /usr/lib64/node as an arch-specific module dir when appropriate
Patch3:		%{name}-lib64path.patch
Patch5:		uv-fpic.patch
URL:		http://www.nodejs.org/
BuildRequires:	c-ares-devel
BuildRequires:	gcc >= 5:4.0
BuildRequires:	http-parser-devel >= 2.0
BuildRequires:	libstdc++-devel
BuildRequires:	libuv-devel >= 0.10
BuildRequires:	openssl-devel
BuildRequires:	pkgconfig
BuildRequires:	python >= 1:2.5.2
BuildRequires:	python-jsmin
BuildRequires:	rpm >= 4.4.9-56
BuildRequires:	rpmbuild(macros) >= 1.219
BuildRequires:	sed >= 4.0
BuildRequires:	v8-devel >= 3.15.11.10
BuildRequires:	zlib-devel
BuildConflicts:	eio
Obsoletes:	nodejs-waf
ExclusiveArch:	%{ix86} %{x8664} arm
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%define		sover	%(echo %{version} | cut -d. -f2)

%description
Node.js is a platform built on Chrome's JavaScript runtime for easily
building fast, scalable network applications. Node.js uses an
event-driven, non-blocking I/O model that makes it lightweight and
efficient, perfect for data-intensive real-time applications that run
across distributed devices.

%package devel
Summary:	Development headers for nodejs
Group:		Development/Libraries
Requires:	%{name} = %{version}-%{release}
Requires:	c-ares-devel
Requires:	gcc
Requires:	http-parser-devel
Requires:	libstdc++-devel
Requires:	libuv-devel
Requires:	openssl-devel
Requires:	v8-devel
Requires:	zlib-devel

%description devel
Development headers for nodejs.

%package doc
Summary:	Evented I/O for V8 JavaScript - documentation
Group:		Documentation

%description doc
Node.js is a server-side JavaScript environment that uses an
asynchronous event-driven model. Node's goal is to provide an easy way
to build scalable network programs.

This package contains the documentation for nodejs.

%prep
%setup -q -n node-v%{version}
%patch1 -p1
%if %{_lib} == "lib64"
%patch3 -p1
%else
%patch2 -p1
%endif
%patch5 -p1

grep -r '#!.*env python' -l . | xargs %{__sed} -i -e '1 s,#!.*env python,#!%{__python},'

rm -r deps

%build
# CC used only to detect if CC is clang, not used for compiling
CC="%{__cc}" \
CXX="%{__cxx}" \
GYP_DEFINES="soname_version=%{sover}" \
./configure \
	--shared-v8 \
	--shared-zlib \
	--shared-openssl \
	--shared-cares \
	--shared-libuv \
	--shared-http-parser \
	--without-npm \
	--without-dtrace \
	--prefix=%{_prefix}

# add LFS defines from libuv (RHBZ#892601)
# CXXFLAGS must be exported, as it is needed for make, not gyp
CXXFLAGS="%{rpmcxxflags} -D_LARGEFILE_SOURCE -D_FILE_OFFSET_BITS=64 -fPIC" \
LDFLAGS="%{rpmldflags}" \
%{__make} -C out V=1 BUILDTYPE=Release

%install
rm -rf $RPM_BUILD_ROOT
%{__make} justinstall \
	DESTDIR=$RPM_BUILD_ROOT \
	LIBDIR=%{_lib}

# no dtrace on linux
%{__rm} -r $RPM_BUILD_ROOT%{_prefix}/lib/dtrace/node.d

lib=$(basename $RPM_BUILD_ROOT%{_libdir}/libnode.so.*.*.*)
ln -s $lib $RPM_BUILD_ROOT%{_libdir}/libnode.so.10
ln -s $lib $RPM_BUILD_ROOT%{_libdir}/libnode.so

echo '.so man1/node.1' > $RPM_BUILD_ROOT%{_mandir}/man1/nodejs.1

install -d $RPM_BUILD_ROOT%{_includedir}/node
cp -p src/*.h $RPM_BUILD_ROOT%{_includedir}/node

# install for node-gyp
install -d $RPM_BUILD_ROOT%{_usrsrc}/%{name}
cp -p common.gypi $RPM_BUILD_ROOT%{_usrsrc}/%{name}
ln -s %{_includedir}/node $RPM_BUILD_ROOT%{_usrsrc}/%{name}/src

# for compat of fedora derivered scripts (shebangs)
ln -s node $RPM_BUILD_ROOT%{_bindir}/nodejs

# globally installed node modules (noarch)
install -d $RPM_BUILD_ROOT%{_prefix}/lib/node_modules

# default searchpaths
install -d $RPM_BUILD_ROOT{%{_libdir},%{_prefix}/lib}/node

# create pkgconfig
install -d $RPM_BUILD_ROOT%{_pkgconfigdir}
cat <<'EOF' > $RPM_BUILD_ROOT%{_pkgconfigdir}/%{name}.pc
version=%{version}
prefix=%{_prefix}
libdir=${prefix}/%{_lib}
includedir=${prefix}/include/node

Name: nodejs
Description: Evented I/O for V8 JavaScript.
Version: ${version}
Cflags: -I${includedir}
EOF

# install documentation
install -d $RPM_BUILD_ROOT%{_docdir}/%{name}-doc-%{version}
cp -a doc/api/* $RPM_BUILD_ROOT%{_docdir}/%{name}-doc-%{version}
rm $RPM_BUILD_ROOT%{_docdir}/%{name}-doc-%{version}/*.markdown
rm $RPM_BUILD_ROOT%{_docdir}/%{name}-doc-%{version}/*.json

%clean
rm -rf $RPM_BUILD_ROOT

%post	-p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%defattr(644,root,root,755)
%doc README.md AUTHORS ChangeLog LICENSE
%attr(755,root,root) %{_bindir}/node
%attr(755,root,root) %{_bindir}/nodejs
%attr(755,root,root) %{_libdir}/libnode.so.*.*.*
%ghost %{_libdir}/libnode.so.10
%if "%{_lib}" != "lib"
%dir %{_libdir}/node
%endif
%dir %{_prefix}/lib/node
%dir %{_prefix}/lib/node_modules
%{_mandir}/man1/node.1*
%{_mandir}/man1/nodejs.1

%files devel
%defattr(644,root,root,755)
%{_libdir}/libnode.so
%{_includedir}/node
%{_pkgconfigdir}/nodejs.pc
%{_usrsrc}/%{name}

%files doc
%defattr(644,root,root,755)
%doc %{_docdir}/%{name}-doc-%{version}
%changelog
* Sat Oct 26 2013 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/nodejs.git;a=log;h=master

* Sat Oct 26 2013 Elan Ruusamäe <glen@delfi.ee> cf110c0
- up to 0.10.21

* Thu Aug 01 2013 Elan Ruusamäe <glen@delfi.ee> e3e8568
- ensure no deps being used

* Thu Aug 01 2013 Elan Ruusamäe <glen@delfi.ee> d8825fb
- up to 0.10.15

* Sun Apr 28 2013 Elan Ruusamäe <glen@delfi.ee> f366a63
- up to 0.10.5 (2013.04.23)

* Mon Apr 08 2013 Elan Ruusamäe <glen@delfi.ee> a11025a
- fix flags passing

* Mon Apr 08 2013 Elan Ruusamäe <glen@delfi.ee> dc60a63
- make soname_version configurable. at least in gyp side

* Mon Apr 08 2013 Elan Ruusamäe <glen@delfi.ee> c7c0bb6
- cleanup

* Mon Apr 08 2013 Elan Ruusamäe <glen@delfi.ee> f9cee3b
- correct soname, it should be "10", i.e without minor

* Mon Apr 08 2013 Elan Ruusamäe <glen@delfi.ee> 536f9f5
- use sed to fixup shebangs, not carry around huge patch for that

* Sun Apr 07 2013 Elan Ruusamäe <glen@delfi.ee> 96f19ba
- update deps for -devel package

* Sun Apr 07 2013 Elan Ruusamäe <glen@delfi.ee> e427e9b
- use system http parser library

* Sun Apr 07 2013 Elan Ruusamäe <glen@delfi.ee> 8939ac2
- use system libuv

* Sun Apr 07 2013 Elan Ruusamäe <glen@delfi.ee> cd4c73a
- BR: openssl-devel, pkgconfig, zlib-devel

* Sun Apr 07 2013 Elan Ruusamäe <glen@delfi.ee> c1c359b
- use system c-ares

* Sun Apr 07 2013 Elan Ruusamäe <glen@delfi.ee> d5764a4
- install extra files for node-gyp; expand license names

* Thu Apr 04 2013 Aria <aredridel@nbtsc.org> a25fcb5
- Restore BC: eio

* Thu Apr 04 2013 Elan Ruusamäe <glen@delfi.ee> d3a7354
- drop ac support; py25 required

* Thu Apr 04 2013 Elan Ruusamäe <glen@delfi.ee> 4174c07
- formatting, cleanups; automate library symlinks

* Thu Apr 04 2013 Aria <aredridel@nbtsc.org> 9dc0bda
- v0.10.3

* Tue Mar 12 2013 Aria <aredridel@nbtsc.org> 6c755a6
- Merge branch 'devel'

